##  Limitations
  * Previews are read-only. You cannot modify shapes, relations, labels, or layout.
  * Views are adjustable but not persistent. You can apply views to a preview, but these adjustments aren't saved. They reset when you refresh or reopen the page.
  * You can preview up to five fact sheets at a time. You can preview only fact sheets that have types matching the base fact sheet type of the template.
  * You can't save a preview directly, but you can save it as a diagram.
